@@ -1,11 +1,11 @@
 package Data::DPath;
-# git description: v0.50-7-gf0eb22a
+# git description: v0.51-9-ga9c0a52
 
 BEGIN {
   $Data::DPath::AUTHORITY = 'cpan:SCHWIGON';
 }
 # ABSTRACT: DPath is not XPath!
-$Data::DPath::VERSION = '0.51';
+$Data::DPath::VERSION = '0.52';
 use 5.008;
 use strict;
 use warnings;
@@ -82,10 +82,10 @@ Data::DPath - DPath is not XPath!
              };
  
  # Perl 5.8 style
- @resultlist = dpath('/AAA/*/CCC')->match($data);   # ( ['XXX', 'YYY', 'ZZZ'], [ 'RR1', 'RR2', 'RR3' ] )
+ my @resultlist = dpath('/AAA/*/CCC')->match($data); # ( ['XXX', 'YYY', 'ZZZ'], [ 'RR1', 'RR2', 'RR3' ] )
  
  # Perl 5.10 style using overloaded smartmatch operator
- $resultlist = $data ~~ dpath '/AAA/*/CCC';         # [ ['XXX', 'YYY', 'ZZZ'], [ 'RR1', 'RR2', 'RR3' ] ]
+ my $resultlist = $data ~~ dpath '/AAA/*/CCC';        # [ ['XXX', 'YYY', 'ZZZ'], [ 'RR1', 'RR2', 'RR3' ] ]
 
 Note that the C<match()> function returns an array but the overloaded
 C<~~> operator returns an array reference (that's a limitation of
@@ -475,7 +475,7 @@ or chain filters:
 This way you do not need to stuff many filters together into one huge
 killer expression and can more easily maintain them.
 
-See L<Filters|Filters> for more details on filters.
+See L<Filters|Data::DPath::Filters> for more details on filters.
 
 =item If you need those special elements to be not special but as
 key names, just quote them:
